@@ -1,9 +1,9 @@
-from pyclvm._common.session import get_session
+from ec2instances.common.session import get_session
 
 
 def stop(identifier: str, **kwargs: str) -> None:
     """
-    Terminate ssm session
+    terminate ssm session
 
     Args:
         identifier (str): SSM session ID
